pub struct ChunkEntityUnloadStart {
pub retained: Vec<SharedEntity>,
pub tracking_stopped: Vec<SharedEntity>,
pub ticking_stopped: Vec<SharedEntity>,
}Expand description
Entity changes produced when a chunk starts unloading.
Fields
retained: Vec<SharedEntity>Entities removed from live ownership and retained for chunk recovery.
tracking_stopped: Vec<SharedEntity>Entities whose tracker visibility should stop for this chunk transition.
ticking_stopped: Vec<SharedEntity>Entities whose ticking should stop for this chunk transition.